import sys
from Crypto.Cipher import AES
from Crypto.Util.Padding import pad, unpad


# encrypt a text with a password
def encrypt(data, password):
    """Return iv and content in hex"""

    cipher = AES.new(password.encode(), AES.MODE_CBC)
    cypher_text_bytes = cipher.encrypt(pad(data.encode(), AES.block_size))

    return cipher.iv.hex() + ':' + cypher_text_bytes.hex()

# decrypt a text with a password
def decrypt(data, password):
    """Return decrypted string in utf-8"""

    try:
        content = data.split(':')

        iv = bytes(bytearray.fromhex(content[0]))
        cipher_text = bytes(bytearray.fromhex(content[1]))

        cipher = AES.new(password.encode(), AES.MODE_CBC, iv)
        return unpad(cipher.decrypt(cipher_text), AES.block_size).decode('utf-8')
    except ValueError:
        print("There was an error")
        raise ValueError



import sys
import os
import argparse

import tenc


def main(args=None):
    parser = argparse.ArgumentParser(description='Encrypt and decrypt files')

    parser.add_argument('-f', dest='path', help='Path to file', required=True)
    parser.add_argument('-p', dest='password', help='The password', required=True)
    parser.add_argument('-d', action='store_true', help='Should decrypt otherwise encrypt')

    args = parser.parse_args()


    if not args.d:
        filename = args.path + '.enc'

        try:
            with open(args.path, 'r') as plainFile:
                with open(filename, 'w') as f:
                    f.write(tenc.encrypt(plainFile.read(), args.password))
                    print('{} encrypted and saved as {}'.format(args.path, filename))
                    f.close()

                plainFile.close()
        except FileNotFoundError:
            print('{} not found'.format(args.path))
    else:
        filename = os.path.join(os.path.dirname(args.path), 'dec_' + os.path.basename(args.path).replace('.enc', ''))

        try:
            with open(args.path, 'r') as encryptedFile:
                with open(filename, 'w') as f:
                    decrypted = tenc.decrypt(encryptedFile.read(), args.password)
                    if decrypted:
                        f.write(decrypted)
                        print('{} decrypted and saved as {}'.format(args.path, filename))
                    f.close()

                encryptedFile.close()
        except FileNotFoundError:
            print('{} not found'.format(args.path))



if __name__ == "__main__":
    sys.exit(main())




#!/usr/bin/env python

from setuptools import setup, find_packages

setup(name='tenc',
      version='1.1.1',
      description='A small package to de- and encrypt strings',
      author='Philip Stapelfeldt',
      author_email='p.stapelfeldt@nanogiants.de',
      packages=find_packages(exclude=["tests"]),
      entry_points={
              'console_scripts': [
                  'tenc = tenc.cli:main',
              ],
      },
      install_requires=[
          'PyCryptodome',
      ],
      python_requires='>=3.6'
      )
